=======
HISTORY
=======

0.2.0 (January 5th, 2022)
=========================

Bug fix release.

* Bug: Fix ``/api/errorlist/`` AttributeError bug (#5)
* Feature: Add ``/api/flush/`` endpoint to flush the error manager (#4)
* Add tests (#1)
* Improve API docs

Tried to feed Kent a banana. Kent peered at it and then put it down.


0.1.0 (January 4th, 2022)
=========================

Initial release with minimally viable feature set.

* capture errors and keep them in memory
* API endpoint to list errors
* API endpoint to fetch error

Fed Kent some pears. Kent loves pears.
